@@ -13,7 +13,7 @@ Readonly::Scalar our $DOT => q{.};
 Readonly::Scalar our $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Read graph subroutine.
 sub _read_graph {
@@ -142,14 +142,21 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Graph::Reader>,
-L<Graph::Reader::Dot>,
-L<Graph::Reader::HTK>,
-L<Graph::Reader::LoadClassHierarchy>,
-L<Graph::Reader::UnicodeTree>,
-L<Graph::Reader::TGF>,
-L<Graph::Reader::TGF::CSV>,
-L<Graph::Reader::XML>.
+=over
+
+=item L<Graph::Reader>
+
+base class for Graph file format readers
+
+=item L<Task::Graph::Reader>
+
+Install the Graph::Reader modules.
+
+=item L<Task::Graph::Writer>
+
+Install the Graph::Writer modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -163,11 +170,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014 Michal Špaček
+ © 2014-2015 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
